@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import ConnectionTypeType, MemberPermissionsType, PermissionsType
 from .paginator import DescribeEnvironmentMembershipsPaginator, ListEnvironmentsPaginator
@@ -60,20 +60,25 @@ class Exceptions:
     TooManyRequestsException: Type[BotocoreClientError]
 
 
-class Cloud9Client:
+class Cloud9Client(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        Cloud9Client exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#can_paginate)
         """
 
@@ -96,7 +101,7 @@ class Cloud9Client:
         Cloud (Amazon EC2) instance, and then connects from the instance to the
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.create_environment_ec2)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.create_environment_ec2)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#create_environment_ec2)
         """
 
@@ -106,7 +111,7 @@ class Cloud9Client:
         """
         Adds an environment member to an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.create_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.create_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#create_environment_membership)
         """
 
@@ -114,7 +119,7 @@ class Cloud9Client:
         """
         Deletes an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.delete_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.delete_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#delete_environment)
         """
 
@@ -122,7 +127,7 @@ class Cloud9Client:
         """
         Deletes an environment member from an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.delete_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.delete_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#delete_environment_membership)
         """
 
@@ -139,7 +144,7 @@ class Cloud9Client:
         Gets information about environment members for an Cloud9 development
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.describe_environment_memberships)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.describe_environment_memberships)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environment_memberships)
         """
 
@@ -149,7 +154,7 @@ class Cloud9Client:
         """
         Gets status information for an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.describe_environment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.describe_environment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environment_status)
         """
 
@@ -159,7 +164,7 @@ class Cloud9Client:
         """
         Gets information about Cloud9 development environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.describe_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.describe_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environments)
         """
 
@@ -173,7 +178,7 @@ class Cloud9Client:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#generate_presigned_url)
         """
 
@@ -183,7 +188,7 @@ class Cloud9Client:
         """
         Gets a list of Cloud9 development environment identifiers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.list_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.list_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#list_environments)
         """
 
@@ -191,7 +196,7 @@ class Cloud9Client:
         """
         Gets a list of the tags associated with an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#list_tags_for_resource)
         """
 
@@ -199,7 +204,7 @@ class Cloud9Client:
         """
         Adds tags to an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#tag_resource)
         """
 
@@ -207,7 +212,7 @@ class Cloud9Client:
         """
         Removes tags from an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#untag_resource)
         """
 
@@ -217,7 +222,7 @@ class Cloud9Client:
         """
         Changes the settings of an existing Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.update_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.update_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#update_environment)
         """
 
@@ -228,7 +233,7 @@ class Cloud9Client:
         Changes the settings of an existing environment member for an Cloud9 development
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Client.update_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Client.update_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#update_environment_membership)
         """
 
@@ -237,7 +242,7 @@ class Cloud9Client:
         self, operation_name: Literal["describe_environment_memberships"]
     ) -> DescribeEnvironmentMembershipsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/paginators.html#describeenvironmentmembershipspaginator)
         """
 
@@ -246,6 +251,6 @@ class Cloud9Client:
         self, operation_name: Literal["list_environments"]
     ) -> ListEnvironmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/paginators.html#listenvironmentspaginator)
         """
